/*

   Demonstration of ELSA PolyTIGA capabilities.

   Hardware requirements :
     Two Gemini boards with equal pixel size and screen resolution.

   Software requirements :
     ELSA TIGA Version 2.01E or greater.
     MSC 5.1 or 6.0 compiler.
     Use SPLYTIGA.OBJ for small model and LPLYTIGA.OBJ for large model.

   Using PolyTIGA you are able to write TIGA programs running on up
   to 6 Gemini boards. These boards MUST have equal pixel sizes AND
   screen resolutions. The video timings can differ.

   This program shows how to initialize and use the ELSA PolyTIGA
   capabilities to drive two boards.

   Program flow :
     Initialization of two Gemini boards.
     Drawing of an identification text on both boards.
     Downloading of graphic primitives on both boards.
     Drawing of a line on both boards.
     Exit TIGA.


   ELSA GmbH
     Stefan Kriebel 14.06.91
*/

#include <stdio.h>
#include <stdlib.h>
#include <tiga.h>
#include <extend.h>
#include <typedefs.h>
#include <polytiga.h>

#define DIM( x ) ( sizeof( x ) / sizeof( x[0] ) )

/*
** This array defines the number and the i/o addresses of all boards
** which should be accessable. The first i/o address MUST be the one
** of the board which was used to generate TIGA.CFG with the TIGACFG
** utility.
*/
ushort board_array[] = { 0x120, 0x128 };
/*                          ^      ^
**          first board ----+      |
**          second board ----------+
*/

ushort xres,yres;
CONFIG config;

void main(int argc, char **argv)
{
  int    i, j;
  long   result;

  /* TIGA initialization */
  if( ( result = tiga_set( CD_OPEN ) ) < 0 )
  { printf( "\nTIGACD error %d", result );
    exit( 1 );
  }

  /*
  ** WARNING :
  **   The following initialization of PolyTIGA succeeds only if both
  **   Gemini's has been initialized with GMIBOOT. The first one already
  **   is, otherwise TIGACD would have failed, but the second one (and
  **   the following if you use more than two) may be not. So, be sure
  **   to have executed a "GMIBOOT -b0x128" command before using this
  **   program.
  */
  context_init( DIM( board_array ), board_array );

  /*
  ** Now all boards are ready, the TIGAGM.OUT file has been loaded on
  ** all boards. The first board is active now. Read in the configuration.
  */
  get_config( &config );
  xres = config.mode.disp_hres;
  yres = config.mode.disp_vres;

  /* Draw two different messages on both boards */

  context_switch( 0 );   /* select the first one */
  text_out(  0, 0, "this is board the first board" );

  context_switch( 1 );   /* select the second one */
  text_out(  0, 0, "this is board the second board" );

  /* Load graphic primitives */

  for( i = 0; i < DIM( board_array ); i++ )
  { context_switch( i );
    if( ( result = install_primitives() ) < 0 )
    { printf("\nGraphics library load error on board %d, error = %d",
	      i, result );
      exit( 1 );
    }
  }

  /* Draw two different lines */
  context_switch( 0 );
  draw_line( 0, 0, xres - 1, yres - 1 );

  context_switch( 1 );
  draw_line( 0, yres - 1, xres - 1, 0 );

  /* End of demonstration */

  tiga_set( CD_CLOSE );
  exit(0);
}

